# Experiments (Markdown extensions) 
 
--- 
Try [markdown/examples](/web/docs/markdown/examples) for a live markdown editor

### Mermaid extension
Here is a Mermaid diagram:

```mermaid
graph TD;
    A-->B;
    A-->C;
    B-->D;
    C-->D;
```

### Video extension

Here is a video: 

[video:https://470426667096-cbr.s3.eu-west-2.amazonaws.com/cbr_website_static/assets/videos/video-tcb__introduction__27-feb-2024.mp4]
